@@ -50,6 +50,7 @@ import org.apache.tomcat.util.buf.HexUtils;
 import org.apache.tomcat.util.collections.SynchronizedStack;
 import org.apache.tomcat.util.modeler.Registry;
 import org.apache.tomcat.util.net.Acceptor.AcceptorState;
+import org.apache.tomcat.util.net.SSLHostConfigCertificate.StoreType;
 import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.threads.LimitLatch;
 import org.apache.tomcat.util.threads.ResizableExecutor;
@@ -374,14 +375,20 @@ public abstract class AbstractEndpoint<S,U> {
     protected void logCertificate(SSLHostConfigCertificate certificate) {
         SSLHostConfig sslHostConfig = certificate.getSSLHostConfig();
 
-        String certificateSource = certificate.getCertificateKeystoreFile();
-        if (certificateSource == null) {
-            certificateSource = certificate.getCertificateKeyFile();
-        }
+        String certificateInfo;
 
-        String keyAlias = certificate.getCertificateKeyAlias();
-        if (keyAlias == null) {
-            keyAlias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+        if (certificate.getStoreType() == StoreType.PEM) {
+            // PEM file based
+            certificateInfo = sm.getString("endpoint.tls.info.cert.pem", certificate.getCertificateKeyFile(),
+                    certificate.getCertificateFile(), certificate.getCertificateChainFile());
+        } else {
+            // Keystore based
+            String keyAlias = certificate.getCertificateKeyAlias();
+            if (keyAlias == null) {
+                keyAlias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+            }
+            certificateInfo =
+                    sm.getString("endpoint.tls.info.cert.keystore", certificate.getCertificateKeystoreFile(), keyAlias);
         }
 
         String trustStoreSource = sslHostConfig.getTruststoreFile();
@@ -393,7 +400,7 @@ public abstract class AbstractEndpoint<S,U> {
         }
 
         getLogCertificate().info(sm.getString("endpoint.tls.info", getName(), sslHostConfig.getHostName(),
-                certificate.getType(), certificateSource, keyAlias, trustStoreSource));
+                certificate.getType(), certificateInfo, trustStoreSource));
 
         if (getLogCertificate().isDebugEnabled()) {
             String alias = certificate.getCertificateKeyAlias();
@@ -420,7 +427,7 @@ public abstract class AbstractEndpoint<S,U> {
             MessageDigest sha512Digest = MessageDigest.getInstance("SHA-256");
             sha512Digest.update(certBytes);
             sb.append(HexUtils.toHexString(sha512Digest.digest()));
-            // SHA-256 fingerprint
+            // SHA-1 fingerprint
             sb.append("\nSHA-1 fingerprint: ");
             MessageDigest sha1Digest = MessageDigest.getInstance("SHA-1");
             sha1Digest.update(certBytes);
